@@ -28,10 +28,13 @@ typedef struct RtreeIndex_t *RtreeIndex;
 
 RtreeIndex RtreeIndex_new(char* filename, unsigned long nPagesize, int load);
 void RtreeIndex_del(RtreeIndex index);
+void RtreeIndex_deleteData(RtreeIndex index, long id, 
+        double *min, double *max);
 void RtreeIndex_insertData(RtreeIndex index, long id, 
         double *min, double *max);
+int RtreeIndex_isValid(RtreeIndex index);
 PyObject *RtreeIndex_intersects(RtreeIndex index, double *min, double *max);
-
+PyObject *RtreeIndex_nearestNeighbors(RtreeIndex index, uint32_t num_results, double *min, double *max);
 #ifdef __cplusplus
 } // extern "C"
 #endif
